Loupe
=====
|build status| |coverage| |docs status| 

Loupe is a Python library for solving parametric optimization problems. Loupe makes 
it easy to build and manipulate numerical models and efficiently solve optimization 
problems using built-in algorithmic differentiation (autograd).

* **Documentation:** https://loupe.readthedocs.io/
* **Releases:** https://pypi.org/project/loupe/
* **Code:** https://github.com/andykee/loupe/
* **Issue tracker:** https://github.com/andykee/loupe/issues/

Loupe is still under active development and new features continue to be added. Until
Loupe reaches version 1.0, the API is not guaranteed to be stable, but changes breaking
backwards compatibility will be noted.

Installing
----------
Install and update Loupe using `pip`_:

.. code-block:: text

    pip install loupe


.. _pip: https://pip.pypa.io/en/stable/quickstart/

.. |build status| image:: https://travis-ci.com/andykee/loupe.svg?branch=master
    :target: https://travis-ci.com/andykee/loupe

.. |coverage| image:: https://coveralls.io/repos/github/andykee/loupe/badge.svg
    :target: https://coveralls.io/github/andykee/loupe

.. |docs status| image:: https://readthedocs.org/projects/loupe/badge/?version=latest
    :target: https://loupe.readthedocs.io/en/latest/?badge=latest